==> mdm-rpc-0.0.31-sources.jar: com/chinayanghe/msp/mdm/vo/franchiser/CompanyProductPriceVo.java <==
package com.chinayanghe.msp.mdm.vo.franchiser;

import java.io.Serializable;
import java.util.Date;

/**
 * 公司产品价格信息
 * User: wangfl
 * Date: 17/5/16
 * Time: 下午8:05
 */
public class CompanyProductPriceVo implements Serializable {
    private static final long serialVersionUID = -8082755603375838203L;
    /**
     * 数据库中的id
     */
    private String id;

    /**
     * 公司编码
     */
    private String companyCode;

    /**
     * 分销渠道编码
     */
    private String channelCode;

    /**
     * 分销渠道名称
     */
    private String channelName;

    /**
     * 省编码
     */
    private String provinceCode;

    /**
     * 省名称
     */
    private String provinceName;

    /**
     * 市编码
     */
    private String cityCode;

    /**
     * 市名称
     */
    private String cityName;

    /**
     *品类编码
     */
    private String productTypeCode;

    /**
     *品牌编码
     */
    private String productBrandCode;

    /**
     *系列编码
     */
    private String seriesCode;

    /**
     *大类编码
     */
    private String bigLevelCode;

    /**
     *小类编码
     */
    private String smallLevelCode;

    /**
     * 产品编码
     */
    private String productCode;

    /**
     * 价格类型编码
     */
    private String priceTypeCode;

    /**
     * 价格类型名称
     */
    private String priceTypeName;

    /**
     * 价格
     */
    private String price;

    /**
     * 价格单位
     */
    private String unit;

    /**
     * 货币
     */
    private String currency;

    /**
     * 数量
     */
    private long num;

    /**
     * 创建时间
     */
    private Date createDate;
    /**
     * 最近更新时间
     */
    private Date updateDate;

    /**
     * 状态 0删除 1正常
     */
    private Integer enableStatus;

    /**
     * 有效开始时间
     */
    private Date startDate;

    /**
     * 有效结束时间
     */
    private Date endDate;
    /**
     * 01 新增 02 修改 03 删除
     */
    private String omact;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCompanyCode() {
        return companyCode;
    }

    public void setCompanyCode(String companyCode) {
        this.companyCode = companyCode;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getProvinceCode() {
        return provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }

    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }

    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public String getProductTypeCode() {
        return productTypeCode;
    }

    public void setProductTypeCode(String productTypeCode) {
        this.productTypeCode = productTypeCode;
    }

    public String getProductBrandCode() {
        return productBrandCode;
    }

    public void setProductBrandCode(String productBrandCode) {
        this.productBrandCode = productBrandCode;
    }

    public String getSeriesCode() {
        return seriesCode;
    }

    public void setSeriesCode(String seriesCode) {
        this.seriesCode = seriesCode;
    }

    public String getBigLevelCode() {
        return bigLevelCode;
    }

    public void setBigLevelCode(String bigLevelCode) {
        this.bigLevelCode = bigLevelCode;
    }

    public String getSmallLevelCode() {
        return smallLevelCode;
    }

    public void setSmallLevelCode(String smallLevelCode) {
        this.smallLevelCode = smallLevelCode;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getPriceTypeCode() {
        return priceTypeCode;
    }

    public void setPriceTypeCode(String priceTypeCode) {
        this.priceTypeCode = priceTypeCode;
    }

    public String getPriceTypeName() {
        return priceTypeName;
    }

    public void setPriceTypeName(String priceTypeName) {
        this.priceTypeName = priceTypeName;
    }

    public String getPrice() {
        return price;
    }

    public void setPrice(String price) {
        this.price = price;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public long getNum() {
        return num;
    }

    public void setNum(long num) {
        this.num = num;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getOmact() {
        return omact;
    }

    public void setOmact(String omact) {
        this.omact = omact;
    }
}

==> mdm-rpc-0.1.93-sources.jar: com/chinayanghe/msp/mdm/vo/franchiser/CompanyProductPriceVo.java <==
package com.chinayanghe.msp.mdm.vo.franchiser;

import java.io.Serializable;
import java.util.Date;

/**
 * 公司产品价格信息
 * User: wangfl
 * Date: 17/5/16
 * Time: 下午8:05
 */
public class CompanyProductPriceVo implements Serializable {
    private static final long serialVersionUID = -8082755603375838203L;
    /**
     * 数据库中的id
     */
    private String id;

    /**
     * 公司编码
     */
    private String companyCode;

    /**
     * 分销渠道编码
     */
    private String channelCode;

    /**
     * 分销渠道名称
     */
    private String channelName;

    /**
     * 省编码
     */
    private String provinceCode;

    /**
     * 省名称
     */
    private String provinceName;

    /**
     * 市编码
     */
    private String cityCode;

    /**
     * 市名称
     */
    private String cityName;

    /**
     *品类编码
     */
    private String productTypeCode;

    /**
     *品牌编码
     */
    private String productBrandCode;

    /**
     *系列编码
     */
    private String seriesCode;

    /**
     *大类编码
     */
    private String bigLevelCode;

    /**
     *小类编码
     */
    private String smallLevelCode;

    /**
     * 产品编码
     */
    private String productCode;

    /**
     * 价格类型编码
     */
    private String priceTypeCode;

    /**
     * 价格类型名称
     */
    private String priceTypeName;

    /**
     * 价格
     */
    private long price;

    /**
     * 价格单位
     */
    private String unit;

    /**
     * 货币
     */
    private String currency;

    /**
     * 数量
     */
    private long num;

    /**
     * 创建时间
     */
    private Date createDate;
    /**
     * 最近更新时间
     */
    private Date updateDate;

    /**
     * 状态 0删除 1正常
     */
    private Integer enableStatus;

    /**
     * 有效开始时间
     */
    private Date startDate;

    /**
     * 有效结束时间
     */
    private Date endDate;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCompanyCode() {
        return companyCode;
    }

    public void setCompanyCode(String companyCode) {
        this.companyCode = companyCode;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getProvinceCode() {
        return provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }

    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }

    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public String getProductTypeCode() {
        return productTypeCode;
    }

    public void setProductTypeCode(String productTypeCode) {
        this.productTypeCode = productTypeCode;
    }

    public String getProductBrandCode() {
        return productBrandCode;
    }

    public void setProductBrandCode(String productBrandCode) {
        this.productBrandCode = productBrandCode;
    }

    public String getSeriesCode() {
        return seriesCode;
    }

    public void setSeriesCode(String seriesCode) {
        this.seriesCode = seriesCode;
    }

    public String getBigLevelCode() {
        return bigLevelCode;
    }

    public void setBigLevelCode(String bigLevelCode) {
        this.bigLevelCode = bigLevelCode;
    }

    public String getSmallLevelCode() {
        return smallLevelCode;
    }

    public void setSmallLevelCode(String smallLevelCode) {
        this.smallLevelCode = smallLevelCode;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getPriceTypeCode() {
        return priceTypeCode;
    }

    public void setPriceTypeCode(String priceTypeCode) {
        this.priceTypeCode = priceTypeCode;
    }

    public String getPriceTypeName() {
        return priceTypeName;
    }

    public void setPriceTypeName(String priceTypeName) {
        this.priceTypeName = priceTypeName;
    }

    public long getPrice() {
        return price;
    }

    public void setPrice(long price) {
        this.price = price;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public long getNum() {
        return num;
    }

    public void setNum(long num) {
        this.num = num;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
}
